pub struct SidequestConfig {
pub enabled: bool,
pub interval_turns: u32,
pub max_eviction_ratio: f32,
pub max_cursors: usize,
pub min_cursor_tokens: usize,
}Expand description
Configuration for LLM-driven side-thread tool output eviction (#1885).
Fields
enabled: boolEnable SideQuest eviction. Default: false.
interval_turns: u32Run eviction every N user turns. Default: 4.
max_eviction_ratio: f32Maximum fraction of tool outputs to evict per pass. Default: 0.5.
max_cursors: usizeMaximum cursor entries in eviction prompt (largest outputs first). Default: 30.
min_cursor_tokens: usizeExclude tool outputs smaller than this token count from eviction candidates.
Default: 100.