PatternStrictness

Enum PatternStrictness 

pub enum PatternStrictness {
    Strict,
    Permissive,
    ProvisionalForDynamicNamespaces,
}
Strictness mode for glob pattern matching against the tool registry.

Controls whether a zero-match glob is a fatal error or a warning.

Variants



Strict

All namespaces are strict — zero-match globs are fatal.



Permissive

All namespaces are permissive — zero-match globs are warnings only.



ProvisionalForDynamicNamespaces

builtin: and skill: globs are strict; mcp:, acp:, a2a: are provisional.

This is the default because MCP servers may not be connected at startup.