#[non_exhaustive]pub enum ToolPolicy {
AllowList(Vec<String>),
DenyList(Vec<String>),
InheritAll,
}Expand description
Tool access policy for a sub-agent.
Controls which tools the sub-agent may call, independent of the global tool denylist.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AllowList(Vec<String>)
Only the listed tool IDs are accessible.
DenyList(Vec<String>)
All tools except those in the list are accessible.
InheritAll
Inherit the full tool set from the parent agent (no additional filtering).