pub struct FleetConfig {
pub refresh_interval_secs: u64,
pub max_sessions: u32,
}Expand description
Configuration for the TUI fleet panel (#3884).
Fields
refresh_interval_secs: u64How often the fleet panel polls the database for updated session data (seconds).
max_sessions: u32Maximum number of sessions to display in the fleet panel.